<?php
/* 
Plugin Name: Thumb-in-Post
Version: 0.93
Plugin URI: http://www.ali-hassan.net/index.php?p=51
Description: Uses custom tags to insert thumbnails, images and objects (Flash/SVG/Quicktime) with or without captions into posts. Code and thumbnails are automatically generated. Inserts three buttons onto the quicktag menu which automate generation of the custom tags. Example custom tag for insertion of a thumbnail with caption: <code>&lt;!--wp:thumb src="image.jpg" cap="This is a caption" --&gt;</code>.
Author: Ali Hassan 
Author URI: http://www.ali-hassan.net
*/ 



//------------------------------------settings------------------------------------

// Get the settings from the config file
$lines = file(get_settings('siteurl')."/wp-content/plugins/thumb-in-post.cfg"); 
 
// work through each line of the config file look for settings
foreach ($lines as $line) {

	// trim spaces from the line
	$line = trim ($line);
	
	// if it's not a comment or blank retrieve the setting
	if (substr($line, 0, 2) != "//" && $line != "") {

		// split the line in two at ==
		$splitLine = explode("==", $line);

		// trim spaces from the first and second halves
		$key = trim ($splitLine[0]);
		$value = trim ($splitLine[1]);

		// make an associative array out of it
		$thumbinpostSettings[$key] = $value;
		}
 	};
	
	// go through and check for values set to the defaults for image path and url settings
	if ($thumbinpostSettings["ImageURL"] == "default") {
			$thumbinpostSettings["ImageURL"] = get_settings('fileupload_url').'/';
			}
			
	if ($thumbinpostSettings["ThumbURL"] == "default") {
			$thumbinpostSettings["ThumbURL"] = $thumbinpostSettings["ImageURL"];
			}
			
	if ($thumbinpostSettings["ImagePath"] == "default") {
			$thumbinpostSettings["ImagePath"] = get_settings('fileupload_realpath').'/';
			}
			
	if ($thumbinpostSettings["ThumbPath"] == "default") {
			$thumbinpostSettings["ThumbPath"] = $thumbinpostSettings["ImagePath"];
			}			


//------------------------------------settings end------------------------------------


//------------------------------------Javascript popups start-------------------------

function javascriptPopupHead() {

global $thumbinpostSettings;

$javascriptcode = "<script type=\"text/javascript\">
//<![CDATA[
function externalLinks() { 


	//if there are no anchors quit
	if (!document.getElementsByTagName) return; 
	//retrieve all the anchors and put them into an array
	var anchors = document.getElementsByTagName(\"a\"); 

	//start looping through the anchors
	for (var i=0; i<anchors.length; i++) { 

	//set the variable anchor to be the current anchor in the anchors array
	var anchor = anchors[i]; 
 
 	//if the anchor has an href and its rel attribute is set to popup, call thr function popup when the link is clicked.
	if (anchor.getAttribute(\"href\") && anchor.getAttribute(\"rel\") == \"popup\") {
		anchor.onclick = popup; 
 	 
		//if the anchor has a class attribute retrieve the image dimensions from it
 		if (anchor.getAttribute(\"class\")) {
			dimensions = anchor.getAttribute(\"class\").split(\"x\");

			//add the padding to give the final window dimensions
			dimensions[0] = parseInt(dimensions[0])+parseInt(".$thumbinpostSettings["JavaScriptPopupHorizontalPadding"].");
			dimensions[1] = parseInt(dimensions[1])+parseInt(".$thumbinpostSettings["JavaScriptPopupVerticalPadding"].");

			}
		
		//now use those settings to set the settings for the window
 		anchor.settings = Array ( \"\", \"width=\"+dimensions[0]+\",height=\"+dimensions[1]+\",scrollbar=yes,menubar=no,top=30,left=10\");
		}

	}
} 

function popup () {
	newWin = window.open(\"\",this.target,this.settings);
	
 	content =  '<html>';
	content += '<head>';
	content += '<link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"".$thumbinpostSettings["JavaScriptPopupStyleSheet"]."\" />';
 	content += '<title>".get_settings('blogname')."</title>';
	content += '</head>';
 	content += '<body>';
	content += '<div class=\"jspopup\">';
 	content += '<img src=\"' + this.href + '\" ></img>';
 	content += '<p><a href=\"#\" onClick=\"self.close()\">Close Window</a></p>';
	content += '</div>';
 	content += '</body>';
	content += '</html>';
	
	
	newWin.document.write(content);
	newWin.document.close();
	newWin.focus();	
return false;
}


window.onload = externalLinks;
//]]>
</script>
";

echo $javascriptcode;
}


if ($thumbinpostSettings["JavascriptPopup"] == "true") {
	add_action('wp_head', 'javascriptPopupHead');
}


//------------------------------------Javascript popups end---------------------------


//--------------------------------thumb-in-post starts--------------------------------

function thumbinpost($data) {

// make sure it gets the settings
global $thumbinpostSettings;

// set the tag that will be used to identify where the picture info is
$tag = $thumbinpostSettings["ThumbTag"];

// This While statement starts looping through $Data looking for the custom tag ($tag)
while(strpos($data, "<!--".$tag." ")) { 
		
// this calls the function getTagFromData which retrieves the attributes from the tag and puts it in an associative array 
list ($entiretag, $attributeValue) = ali_getTagFromData($data, $tag);

// work out what the dimensions of the image should be
$attributeValue = ali_determineImageDimensions ($attributeValue, $tag);

// If a thumbnail doesn't already exist then generate one	
if (!file_exists($thumbinpostSettings["ThumbPath"].$thumbinpostSettings["ThumbPrefix"].$attributeValue["Source"])) {
	// send the attribute values to the image resize function
	ali_imageResize ($attributeValue);
	} 

// get the size of the thumbnail
$thumbinfo = getimagesize($thumbinpostSettings["ThumbURL"].$thumbinpostSettings["ThumbPrefix"].$attributeValue["Source"]);

//check to see if the thumbnail has the same size as the attributes set for it. If not make a new one
if ($thumbinfo[0] != $attributeValue["Width"] || $thumbinfo[1] != $attributeValue["Height"]) {
	// send the attribute values to the image resize function
	ali_imageResize ($attributeValue);
	$thumbinfo = getimagesize($thumbinpostSettings["ThumbURL"].$thumbinpostSettings["ThumbPrefix"].$attributeValue["Source"]);
	}


//Now generate the html code to insert the image into the page

	// attach an id (from $attributeValue['DivId']) to the divstart to give it a unique identity
	$divstart = $thumbinpostSettings["ThumbDivStart"].' '.$attributeValue["DivClass"].'" 
			id="'.$attributeValue["DivId"].'" >';

	// code to build links to the full size image
	$linkstart = '<a href="'.$thumbinpostSettings["ImageURL"].$attributeValue["Source"].'" '.$thumbinpostSettings["Target"].' rel="popup" class="'.$attributeValue["FullSizeImageWidth"].'x'.$attributeValue["FullSizeImageHeight"].'" >';
	$linkend = '</a>';

	//Generate the HTML to display the thumbnail
	$imgCode = $linkstart.
			'<img src="'.$thumbinpostSettings["ThumbURL"].$thumbinpostSettings["ThumbPrefix"].$attributeValue["Source"].'" 			alt="'.	$attributeValue['Alt'].'" width="'.$thumbinfo[0].'"  height="'.$thumbinfo[1].'"></img>'.
			$linkend;

	// start building the code which will replace $entiretag in $data
	if ($attributeValue["Caption"] != "") {
			$replacementCode = $divstart.$imgCode.$thumbinpostSettings["CaptionTagStart"].$linkstart.$thumbinpostSettings["EnlargeIcon"].
					$linkend.$attributeValue["Caption"].$thumbinpostSettings["CaptionTagEnd"].$thumbinpostSettings["ThumbDivEnd"];
			} else 
			{
			$replacementCode = $divstart.$imgCode.$thumbinpostSettings["ThumbDivEnd"];
			};

	$data = str_replace ($entiretag, $replacementCode, $data);

		}

	return $data;

	};

add_filter ('the_content','thumbinpost');

//-----------------Thumb-in-Post ends here--------------------------------------


//---------------Pic-In-Post starts here----------------------------------------

function picinpost($data) {

// make sure it gets the settings
global $thumbinpostSettings;

// set the tag that will be used to identify where the picture info is
$tag = $thumbinpostSettings["PictureTag"];

// extract the image name and the caption (if present from the
while(strpos($data, "<!--".$tag." ")) { 

	// this calls the function getTagFromData which retrieves the image tag from $data
	list ($entiretag, $attributeValue) = ali_getTagFromData($data, $tag);

	// work out what the dimensions of the image should be
	$attributeValue = ali_determineImageDimensions ($attributeValue, $tag);

	//Now generate the html code to insert into the page

	// attach an id (from $attributeValue['DivId']) to the divstart to give it a unique identity
	$divstart = $thumbinpostSettings["PictureDivStart"].' '.$attributeValue["DivClass"].'" id="'.$attributeValue["DivId"].'" >';

	// this is the code to generate the img tag
	$imgCode = '<img src="'.$thumbinpostSettings["ImageURL"].$attributeValue["Source"].'" alt="'.$attributeValue['Alt'].'" width="'.$attributeValue["Width"].'" height="'.	$attributeValue["Height"].'"></img>';

	//start building the code which will replace $entiretag in $data
	if ($attributeValue["Caption"] != "") {
			$replacementCode = $divstart.
						$imgCode.
						$thumbinpostSettings["CaptionTagStart"].
						$attributeValue["Caption"].
						$thumbinpostSettings["CaptionTagEnd"].
						$thumbinpostSettings["PictureDivEnd"];
			} else 
			{
			$replacementCode = $divstart.
						$imgCode.
						$thumbinpostSettings["PictureDivEnd"];
			};

	$data = str_replace ($entiretag, $replacementCode, $data);

	}

return $data;

};

add_filter ('the_content','picinpost');

//--------------------pic-in-post ends--------------------------------------

//---------------object-In-Post starts here----------------------------------------

function objectinpost($data) {

// make sure it gets the settings
global $thumbinpostSettings;

// set the tag that will be used to identify where the picture info is
$tag = $thumbinpostSettings["ObjectTag"];

// extract the image name and the caption (if present from the
while(strpos($data, "<!--".$tag." ")) { 

// this calls the function getTagFromData which retrieves the image tag from $data
list ($entiretag, $attributeValue) = ali_getTagFromData($data, $tag);

//Now generate the html code to insert into the page

// code to build links to the full size image
$linkstart = '<a href="'.$thumbinpostSettings["ImageURL"].
		$attributeValue["Source"].'" '.
		$thumbinpostSettings["Target"].' >';
$linkend = '</a>';

//Need to figure out what type of file it is
$fileExtension = substr($attributeValue["Source"], strlen($attributeValue["Source"])-3, 3);

switch ($fileExtension) {

	case "swf": 	// Flash

		// work out what the dimensions of the image should be
		$attributeValue = ali_determineImageDimensions ($attributeValue, $tag);

		//This code for flash movies should be standards compliant
		$objectInfo = getimagesize($thumbinpostSettings["ImagePath"].$attributeValue["Source"]);
		$objectCode = '<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" 
				codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,40,0" width="'.$attributeValue["Width"].'" height="'.$attributeValue["Height"].'" class="'.$fileExtension.'">
			<param name="movie" value="'.$thumbinpostSettings["ImageURL"].$attributeValue['Source'].'" /> 
			<param name="quality" value="high" />
			<!--[if !IE]> <-->
				<object data="'.$thumbinpostSettings["ImageURL"].$attributeValue['Source'].'" type="application/x-shockwave-flash" width="'.$attributeValue["Width"].'" height="'.$attributeValue["Height"].'" class="'.$fileExtension.'">
					<param name="quality" value="high" />
					<param name="pluginurl" value="http://www.macromedia.com/go/getflashplayer" />
			<p>Error: This object cannot be displayed.</p> </object>   <!--> <![endif]-->
		</object>';
		$captioncode = $thumbinpostSettings["CaptionTagStart"].
				$linkstart.
				$thumbinpostSettings["EnlargeIcon"].
				$linkend.$attributeValue["Caption"].
				$thumbinpostSettings["CaptionTagEnd"];
	break;


	case "svg":	// Scalable vector graphic

		//this code for SVG insertion is standards compliant but doesn't allow proper interactivity on IE/Win
		$objectCode ='<object type="image/svg+xml" class="'.$fileExtension.'" data="'.$thumbinpostSettings["ImageURL"].$attributeValue['Source'].'" width="'.$attributeValue["Width"].'" height="'.$attributeValue["Height"].'" >
				<p>You have not installed an SVG plugin</p></object>';

		//this is what adobe recommends for IE/Win security related reasons (surprise!), but note that <embed> is not valid anything
		//$objectCode ='<embed type="image/svg+xml" class="'.
		//			$fileExtension.'" src="'.
		//			$thumbinpostSettings["ImageURL"].
		//			$attributeValue['Source'].'">';
	
		$captioncode = $thumbinpostSettings["CaptionTagStart"].
				$linkstart.
				$thumbinpostSettings["EnlargeIcon"].
				$linkend.$attributeValue["Caption"].
				$thumbinpostSettings["CaptionTagEnd"];
	break;

	case "mov";	// Apple Quicktime
		$objectCode = '<object classid="clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B" 
				codebase="http://www.apple.com/qtactivex/qtplugin.cab" class="'.$fileExtension.'" width="'.$attributeValue["Width"].'" 	height="'.$attributeValue["Height"].'" >
 				<param name="src" value="'.$thumbinpostSettings["ImageURL"].$attributeValue["Source"].'" />
				<param name="controller" value="true" />
				<!--[if !IE]> <-->
					<object type="video/quicktime" data="'.$thumbinpostSettings["ImageURL"].$attributeValue['Source'].'" class="'.$fileExtension.'" width="'.$attributeValue["Width"].'" height="'.$attributeValue["Height"].'" >
						<param name="controller" value="true" />
				Error: This object cannot be displayed. </object>   <!--> <![endif]-->
			</object>';
		$captioncode = $thumbinpostSettings["CaptionTagStart"].
				$linkstart.
				$thumbinpostSettings["EnlargeIcon"].
				$linkend.$attributeValue["Caption"].
				$thumbinpostSettings["CaptionTagEnd"];
	break;


	
	default:
		$objectCode = "<p>Error: Either this filetype is unsupported at present, 
				the file cannot be found or you have used an incorrect file extension.</p>";

		$captioncode = $thumbinpostSettings["CaptionTagStart"].
				$attributeValue["Caption"].
				$thumbinpostSettings["CaptionTagEnd"];

		break;
	};

	// attach an id (from $attributeValue['DivId']) to the divstart to give it a unique identity
	$divstart = $thumbinpostSettings["ObjectDivStart"].' '.$attributeValue["DivClass"].'" id="'.$attributeValue["DivId"].'" >';

	//start building the code which will replace $entiretag in $data
	if ($attributeValue["Caption"] != "") {
			$replacementCode = $divstart.
						$objectCode.
						$captioncode.
						$thumbinpostSettings["ObjectDivEnd"];
			} else 
			{
			$replacementCode = $divstart.
						$objectCode.
						$thumbinpostSettings["ObjectDivEnd"];
			};

	$data = str_replace ($entiretag, $replacementCode, $data);

	}

return $data;

};

add_filter ('the_content','objectinpost');

//----------------------------------------------object-in-post ends-----------------


//-----------------------------Get info from Tag starts---------------------------------

//this is the function for retrieving the $tag from $data
function ali_getTagFromData($data, $tag) {

// make sure it gets the settings
global $thumbinpostSettings;

	$pattern = "/<!--$tag.*-->/U";
	$regs = array ();
	if(preg_match("/<!--$tag.*-->/U",$data,$regs)) {
			$entiretag = $regs[0];
			} else {
			echo("bugger");
			};

	$attributeType = array( "Source"=>"src", 
				"Caption"=>"cap",
				"Alt Text"=>"alt", 
				"Width"=>"width", 
				"Height"=>"height", 
				"DivId"=>"id", 
				"DivClass"=>"class");
	
	//Start looping through the array
	foreach ($attributeType as $key => $value) {
	
		//Are there any matches for the current attribute in the array?
		if(preg_match("/$attributeType[$key]=\".*\"/U", $entiretag, $match)) {
			
			//If there are pull the associated parameter out ...
			$parameter = substr($match[0], strlen($value)+2, strlen($match[0])-strlen($value)-3);
			
			//... and put it into an array keyed to the attribute type
			$attributeValue[$key] = $parameter;
			} 
			else
			{
			// makes sure that the array is defined for each and every key
			$attributeValue[$key] = "";
			}
	}
	
//Now just tidy up some loose ends ....	

	// if no id was set make it equal the filename, less its file extension
	if (empty($attributeValue["DivId"])) {
		$attributeValue["DivId"] = substr($attributeValue["Source"], 0, strlen($attributeValue["Source"])-4);
		}
		
	// if there's no caption and no alt text put an apology in the alt tag.	
	if (empty($attributeValue["Caption"]) && empty($attributeValue["Alt Text"])) {
		$attributeValue["Alt Text"] = "I'm sorry, I was too lazy to write an alt tag. You should complain.";
		}
				
	// if there's a caption but no alt text make the alt text equal the caption	
	if (isset($attributeValue["Caption"]) && empty($attributeValue["Alt Text"])) {
		$attributeValue["Alt Text"] = $attributeValue["Caption"];
		}
		
	// texturize the caption
	$text = $attributeValue["Caption"];
	$attributeValue["Caption"] = wptexturize ($text);
		
	// and then return the tag and the attributes that were pulled out of it
	return array ($entiretag, $attributeValue);
}

//----------------------------Get info from Tag ends---------------------------------

//------------------------------Image resize starts----------------------------------

function ali_imageResize ($attributeValue) {

// make sure it gets the settings
global $thumbinpostSettings;

	// retrieve file info -- check to see what file type it is
	$imginfo = getimagesize($thumbinpostSettings["ImagePath"].$attributeValue["Source"]);

	// load the image from file into a variable called $img_in
	switch ($imginfo[2]) { 

		case 2:		// jpg
			$img_in = imagecreatefromjpeg($thumbinpostSettings["ImagePath"].$attributeValue["Source"]);
      			break;

		case 3:		// png
			$img_in = imagecreatefrompng($thumbinpostSettings["ImagePath"].$attributeValue["Source"]);
			break;

		default:
			echo('Error: cannot resize images other than JPEG or PNG; or file not found');
	};

	//set the size for the image that will be output
	$img_out_width = $attributeValue["Width"];
	$img_out_height = $attributeValue["Height"];
	
	// create a new image in $img_out with the dimensions $thumbWidth and $img_out_height
	$img_out = imagecreatetruecolor($img_out_width, $img_out_height);

	// now copy $img_in into $img_out
	imagecopyresampled($img_out,$img_in,0,0,0,0,imagesx($img_out),imagesy($img_out),imagesx($img_in),imagesy($img_in));

	// write the image into a file in the thumbnail directory
	switch ($imginfo[2]) {

		case 2:		// jpg
			imagejpeg($img_out, $thumbinpostSettings["ThumbPath"].$thumbinpostSettings["ThumbPrefix"].$attributeValue["Source"], $thumbinpostSettings["JpegQuality"]);
			break;

		case 3:		// png
			imagepng($img_out,  $thumbinpostSettings["ThumbPath"].$thumbinpostSettings["ThumbPrefix"].$attributeValue["Source"]);
			break;

		default: 
			echo('Error: could not write image');
	};
	
	} // end the else statement

//-------------------------------Image resize ends-----------------------------------

// ----------------------Determine Image Dimensions starts---------------------------

function ali_determineImageDimensions ($attributeValue, $tag) {

// make sure it gets the settings
global $thumbinpostSettings;

// get the dimensions of the full size image
$imginfo = getimagesize($thumbinpostSettings["ImageURL"].$attributeValue["Source"]);

//if there's a height specified but no width calculate the width from the aspect ratio
if ($attributeValue["Width"] == "" && $attributeValue["Height"] != "") {
	$img_ratio = $imginfo[0]/$imginfo[1];
	$attributeValue["Width"] = round($img_ratio*$attributeValue["Height"]);
	}

//if there's a width set for the picture in the tag use that, otherwise use the default
if ($attributeValue["Width"] == "") {
	if ($tag == $thumbinpostSettings["ThumbTag"]) {
		$attributeValue["Width"] = $thumbinpostSettings["ThumbWidth"];
		} else {
		$attributeValue["Width"] = $imginfo[0];
		}
	}
	
//if there's a height set for the picture, otherwise work it out from the width and the image's aspect ratio
if ($attributeValue["Height"] == "") {
	$img_ratio = $imginfo[1]/$imginfo[0];
	$attributeValue["Height"] = round($img_ratio*$attributeValue["Width"]);
	}

//put the dimensions of the full size image and file type into $sttributeValue
$attributeValue["FullSizeImageWidth"] = $imginfo[0];
$attributeValue["FullSizeImageHeight"] = $imginfo[1];
$attributeValue["FullSizeImageType"] = $imginfo[2];

return $attributeValue;
}

//-----------------------Determine Image Dimensions starts---------------------------


//-----------------------------------fix_wp_autop starts-----------------------------

//Clean up the mess that wordpress makes of <p>'s enclosing divs

function ali_fix_wpautop ($data) {

	//fix the div's at the ends
	$data = str_replace('<p><div', '<div', $data);

	//fix the div's at the ends
	$data = str_replace('</div></p>', '</div>', $data);
	$data = str_replace("</div>\n</p>", "</div>", $data);

	return $data;
	};

add_filter ('the_content','ali_fix_wpautop');


//----------------------------------------------------fix_wp_autop ends-----------------



//--------------------------User interface stuff down here--------------------------
//THis is the code that puts the 'Thumbnail' button on the write/edit page
//the code is based on the edit button framework by Owen Winkler at www.asymptomatic.net/wp-hacks

//gets the callback function
add_filter('admin_footer', 'ali_thumb_button');

//this is the callback function
function ali_thumb_button() {

// make sure it gets the settings
global $thumbinpostSettings;

	if(strpos($_SERVER['REQUEST_URI'], 'post.php')) {
?>
<script language="JavaScript" type="text/javascript"><!--
	var toolbar = document.getElementById("ed_toolbar");
	<?php
		//Insert one of the following lines for each button you want to add.
		edit_insert_button("Thumbnail", "ali_edInsertThumb", "Insert Thumbnail");
		edit_insert_button("Picture", "ali_edInsertPicture", "Insert Picture");
		edit_insert_button("Object", "ali_edInsertObject", "Insert Object");
	?>
	//Javascript handler for the button
	function ali_edInsertThumb() {
		var myValue = prompt('Enter the filename of the image', '');
			if (myValue) {
				myValue = '<!--<?php echo ($thumbinpostSettings["ThumbTag"]) ?> src="'+ myValue+'"';
					var myCaption = prompt('Enter a caption for the image (Not required, leave blank if you do not want one).', '');
						if (myCaption) {
							myValue = myValue + ' cap="' + myCaption +'" -->'
							} 
							else {
								myValue = myValue + ' -->'
						}
					edInsertContent(edCanvas,myValue);
			}
		}
	function ali_edInsertPicture() {
		var myValue = prompt('Enter the filename of the image', '');
			if (myValue) {
				myValue = '<!--<?php echo ($thumbinpostSettings["PictureTag"]) ?> src="'+ myValue+'"';
					var myCaption = prompt('Enter a caption for the image (Not required, leave blank if you do not want one)', '');
						if (myCaption) {
							myValue = myValue + ' cap="' + myCaption +'" -->'
							} 
							else {
								myValue = myValue + ' -->'
						}
					edInsertContent(edCanvas,myValue);
			}
		}
	function ali_edInsertObject() {
		var myValue = prompt('Enter the filename of the object. Currently supported filetypes are Flash (.swf), Scalable Vector Graphic (.svg) and Quicktime (.mov).', '');
			if (myValue) {
				myValue = '<!--<?php echo ($thumbinpostSettings["ObjectTag"]) ?> src="'+ myValue+'"';
					var myCaption = prompt('Enter a caption for the object (Not required, leave blank if you do not want one)', '');
						if (myCaption) {
							myValue = myValue + ' cap="' + myCaption +'" -->'
							} 
							else {
								myValue = myValue + ' -->'
						}
					edInsertContent(edCanvas,myValue);
			}
		}
//--></script>
<?php
		}
	}

	if(!function_exists('edit_insert_button'))
	{
		//edit_insert_button: Inserts a button into the editor
		function edit_insert_button($caption, $js_onclick, $title = '')
		{
?>
		if(toolbar)
		{
			var theButton = document.createElement('input');
			theButton.type = 'button';
			theButton.value = '<?php echo $caption; ?>';
			theButton.onclick = <?php echo $js_onclick; ?>;
			theButton.className = 'ed_button';
			theButton.title = "<?php echo $title; ?>";
			theButton.id = "<?php echo "ed_{$caption}"; ?>";
			toolbar.appendChild(theButton);
	}
<?php

	}
}

//Copyright Ali Hassan 2004

?>